import request from '@/config/axios'

// 空气质量采集 VO
export interface QualityCollectionVO {
  id: number // 主键
  siteName: string // 站点名称
  city: string // 城市
  type: number // 数据类型
  pm25: number // PM2.s(ugim3)
  pm10: number // PMo(ug/m3
  so2: number // sOz(ug/m3)
  no2: number // NOz(ug/m3)
  no: number // NO(Hg/m3)
  nOx: number // NOx(Hg/m3)
  co: number // CO(mg/m3)
  o3: number // 0з(ug/m3)
  remark: string // 备用1
  remark2: string // 备用2
}

// 空气质量采集 API
export const QualityCollectionApi = {
  // 查询空气质量采集分页
  getQualityCollectionPage: async (params: any) => {
    return await request.get({ url: `/system/quality-collection/page`, params })
  },

  // 查询空气质量采集详情
  getQualityCollection: async (id: number) => {
    return await request.get({ url: `/system/quality-collection/get?id=` + id })
  },

  // 新增空气质量采集
  createQualityCollection: async (data: QualityCollectionVO) => {
    return await request.post({ url: `/system/quality-collection/create`, data })
  },

  // 修改空气质量采集
  updateQualityCollection: async (data: QualityCollectionVO) => {
    return await request.put({ url: `/system/quality-collection/update`, data })
  },

  // 删除空气质量采集
  deleteQualityCollection: async (id: number) => {
    return await request.delete({ url: `/system/quality-collection/delete?id=` + id })
  },

  // 导出空气质量采集 Excel
  exportQualityCollection: async (data:any) => {
    return await request.upload({ url: `/system/quality-collection/upload-excel`, data })
  }
}
