import request from '@/config/axios'

// 企业检查记录表，用于记录与企业相关的环保检查信息。 VO
export interface EnterpriseInspectionsVO {
  id: number // 检查记录ID，主键
  taskId: number // 任务ID
  enterpriseId: number // 企业ID
  tagList: String
}

// 企业检查记录表，用于记录与企业相关的环保检查信息。 API
export const EnterpriseInspectionsApi = {
  // 查询企业检查记录表，用于记录与企业相关的环保检查信息。分页
  getEnterpriseInspectionsPage: async (params: any) => {
    return await request.get({ url: `/system/enterprise-inspections/page`, params })
  },

  // 查询企业检查记录表，用于记录与企业相关的环保检查信息。详情
  getEnterpriseInspections: async (id: number) => {
    return await request.get({ url: `/system/enterprise-inspections/get?id=` + id })
  },

  // 新增企业检查记录表，用于记录与企业相关的环保检查信息。
  createEnterpriseInspections: async (data: EnterpriseInspectionsVO) => {
    return await request.post({ url: `/system/enterprise-inspections/create`, data })
  },

  // 修改企业检查记录表，用于记录与企业相关的环保检查信息。
  updateEnterpriseInspections: async (data: EnterpriseInspectionsVO) => {
    return await request.put({ url: `/system/enterprise-inspections/update`, data })
  },

  // 删除企业检查记录表，用于记录与企业相关的环保检查信息。
  deleteEnterpriseInspections: async (id: number) => {
    return await request.delete({ url: `/system/enterprise-inspections/delete?id=` + id })
  },

  // 导出企业检查记录表，用于记录与企业相关的环保检查信息。 Excel
  exportEnterpriseInspections: async (params) => {
    return await request.download({ url: `/system/enterprise-inspections/export-excel`, params })
  },

  // 导出企业检查记录表，用于记录与企业相关的环保检查信息。 Excel
  inspectionsLogList: async (params: any) => {
    return await request.get({ url: `/system/inspections-log/list`, params })
  },

  //根据 用户id和任务名称查询可以转发的任务
  getListByUserIdAndTaskName: async (params: any) => {
    return await request.get({
      url: `/system/enterprise-inspections/getListByUserIdAndTaskName`,
      params
    })
  },
  // 变更人员ID
  passOn: async (data: any) => {
    return await request.post({ url: `/system/enterprise-inspections/passOn`, data })
  },
  /**
   * 查询企业执法记录
   */
  getListByEnterpriseId: async (params: any) => {
    return await request.get({
      url: `/system/enterprise-inspections/inspectionsByEnterpriseId`,
      params
    })
  },
  /**
   * 获取执法记录日志详情
   */
  getLogDetail:async (id: any) => {
    return await request.get({
      url: `/system/inspections-log/get?id=${id}`,
    })
  },
}
