import request from '@/config/axios'

// 附件信息 VO
export interface FileInfoVO {
  id: number // ID
  attachmentName: string // 文件名
  attachmentPath: string // 文件路径
  attachmentMd5: string // 文件MD5
  unitId: number // 关联ID(日报/案件/行动...)
  type: number // 类别
  status: number // 状态
  deptId: number // 部门ID
  groupId: number // 文件分组ID
  level: number // 文件等级
  permissions: string // 文件权限
}

// 附件信息 API
export const FileInfoApi = {
  // 查询附件信息分页
  getFileInfoPage: async (params: any) => {
    return await request.get({ url: `/system/file-info/page`, params })
  },

  // 查询附件信息详情
  getFileInfo: async (id: number) => {
    return await request.get({ url: `/system/file-info/get?id=` + id })
  },

  // 新增附件信息
  createFileInfo: async (data: any) => {
    return await request.post({ url: `/system/file-info/create`, data })
  },

  // 新增附件信息
  createbatchFileInfo: async (data: any) => {
    return await request.post({ url: `/system/file-info/createbatch`, data })
  },

  // 修改附件信息
  updateFileInfo: async (data) => {
    return await request.put({ url: `/system/file-info/update`, data })
  },

  // 删除附件信息
  deleteFileInfo: async (id: number) => {
    return await request.delete({ url: `/system/file-info/delete?id=` + id })
  },

  // 导出附件信息 Excel
  exportFileInfo: async (params) => {
    return await request.download({ url: `/system/file-info/export-excel`, params })
  },

  // 查询附件信息分页
  getFileInfoList: async (params: any) => {
    return await request.get({ url: `/system/file-info/list`, params })
  },
}
