import request from '@/config/axios'

// 企业 VO
export interface EnterprisesVO {
  id: number // 企业ID，主键
  departmentId: number // 所属部门ID
  userId: number // 邀请人
  type: string // 企业类型
  region: string // 企业所属区域
  enterprisesName: string // 企业名称
  address: string // 企业地址
  enterprisesStatus //企业状态
  contactName: string // 环保负责人姓名
  environmentalContactPhone: string // 企业环保负责人联系电话
  registrationNumber: string // 企业注册号
  introduction: string // 企业图文介绍
  establishmentDate: Date // 企业成立时间
  gpsLocation: string // 企业经纬度
  signRadius: string //签到半径
  managerDeptId: number // 管理部门
  tagList: any
}

// 企业 API
export const EnterprisesApi = {
  // 查询企业分页
  getEnterprisesPage: async (params: any) => {
    return await request.get({ url: `/system/enterprise/pcpage`, params })
  },

  getEnterpriseByUserId: async (params: any) => {
    return await request.get({ url: `/system/enterprise/getEnterpriseByUserId`, params })
  },

  // 查询企业详情
  getEnterprises: async (id: any) => {
    return await request.get({ url: `/system/enterprise/get?id=` + id })
  },

  // 新增企业
  createEnterprises: async (data: EnterprisesVO) => {
    return await request.post({ url: `/system/enterprise/create`, data })
  },
  // PC新增企业
  pccreateEnterprises: async (data: any) => {
    return await request.post({ url: `/system/enterprise/pccreate`, data })
  },

  // 修改企业
  updateEnterprises: async (data: any) => {
    return await request.put({ url: `/system/enterprise/update`, data })
  },

  // 删除企业
  deleteEnterprises: async (id: number) => {
    return await request.delete({ url: `/system/enterprise/delete?id=` + id })
  },

  // 导出企业 Excel
  exportEnterprises: async (params) => {
    return await request.download({ url: `/system/enterprise/export-excel`, params })
  },

  // 标签查询
  tagList: async (params) => {
    return await request.get({ url: `"/system/system/tag-library/list`, params })
  },

  /**
   * 查询企业详情
   * @param id 企业ID
   */
  enterpriseDetail: async (id: any) => {
    return await request.get({ url: `/system/enterprise/pcget?id=` + id })
  }
}
