import request from '@/config/axios'

// 企业资质 VO
export interface EnterpriseQualificationVO {
  id: number // 主键
  enterpriseId: number // 企业ID
  qualificationName: number // 资质名称，例如：排污许可证、环保合格证
  expiryDate: Date // 资质到期日期
  qualificationDescription: string // 资质描述，详细说明资质信息
  updateBy: string // 修改人
  createBy: string // 创建人
  handleDate: Date // 办理日期
  enterpriseAuth: string // 资质编号
}

// 企业资质 API
export const EnterpriseQualificationApi = {
  // 查询企业资质分页
  getEnterpriseQualificationPage: async (params: any) => {
    return await request.get({ url: `/system/enterprise-qualification/page`, params })
  },

  // 查询企业资质分页
  getEnterpriseQualificationPageEnterprise: async (params: any) => {
    return await request.get({ url: `/system/enterprise-qualification/pageEnterprise`, params })
  },

  // 查询企业资质详情
  getEnterpriseQualification: async (id: any) => {
    return await request.get({ url: `/system/enterprise-qualification/get?id=` + id })
  },

  // 新增企业资质
  createEnterpriseQualification: async (data: EnterpriseQualificationVO) => {
    return await request.post({ url: `/system/enterprise-qualification/create`, data })
  },

  // 修改企业资质
  updateEnterpriseQualification: async (data: EnterpriseQualificationVO) => {
    return await request.put({ url: `/system/enterprise-qualification/update`, data })
  },

  // 删除企业资质
  deleteEnterpriseQualification: async (id: number) => {
    return await request.delete({ url: `/system/enterprise-qualification/delete?id=` + id })
  },

  // 导出企业资质 Excel
  exportEnterpriseQualification: async (params) => {
    return await request.download({ url: `/system/enterprise-qualification/export-excel`, params })
  }
}
