import request from '@/config/axios'

// 工作汇报 VO
export interface JobInfoVO {
  id: number // id
  title: string // 汇报标题
  content: string // 汇报内容
  jobDate: Date // 汇报日期
  jobName: string // 汇报人姓名
}

// 工作汇报 API
export const JobInfoApi = {
  // 查询工作汇报分页
  getJobInfoPage: async (params: any) => {
    return await request.get({ url: `/system/job-info/page`, params })
  },

  // 查询工作汇报详情
  getJobInfo: async (id: number) => {
    return await request.get({ url: `/system/job-info/get?id=` + id })
  },

  // 模板信息
  jobDetail: async (id: number) => {
    return await request.get({ url: `/system/job-info/jobDetail?id=` + id })
  },

  // 新增工作汇报
  createJobInfo: async (data: JobInfoVO) => {
    return await request.post({ url: `/system/job-info/create`, data })
  },

  // 修改工作汇报
  updateJobInfo: async (data: JobInfoVO) => {
    return await request.put({ url: `/system/job-info/update`, data })
  },

  // 删除工作汇报
  deleteJobInfo: async (id) => {
    return await request.delete({ url: `/system/job-info/delete?id=` + id })
  },

  // 导出工作汇报 Excel
  exportJobInfo: async (params) => {
    return await request.download({ url: `/system/job-info/export-excel`, params })
  },


}
