import request from '@/config/axios'

// 企业标签 VO
export interface TagLibraryVO {
  id: number // 签的唯一标识，自增主键
  tagName: string // 标签的名称
  parentTagId: number // 父标签的ID
  tagLevel: number // 标签层级（一级、二级、三级）
  tagType: number // 1、企业标签2、执法标签
  sort: number
  tagCode: string
}

// 企业标签 API
export const TagLibraryApi = {
  // 查询企业标签分页
  getTagLibraryPage: async (params: any) => {
    return await request.get({ url: `/system/tag-library/pageInfo`, params })
  },

  // 查询企业标签分页
  childrenList: async (id: number) => {
    return await request.get({ url: `/system/tag-library/childrenList?id=` + id })
  },

  // 查询企业标签详情
  getTagLibrary: async (id: any) => {
    return await request.get({ url: `/system/tag-library/get?id=` + id })
  },

  // 新增企业标签
  createTagLibrary: async (data: TagLibraryVO) => {
    return await request.post({ url: `/system/tag-library/create`, data })
  },

  // 修改企业标签
  updateTagLibrary: async (data: TagLibraryVO) => {
    return await request.put({ url: `/system/tag-library/update`, data })
  },

  // 删除企业标签
  deleteTagLibrary: async (id: number) => {
    return await request.delete({ url: `/system/tag-library/delete?id=` + id })
  },

  tagLibraryList: async (codeList) => {
    return await request.get({ url: `/system/tag-library/list`, params: { codeList } })
  },

  // 导出企业标签 Excel
  exportTagLibrary: async (params) => {
    return await request.download({ url: `/system/tag-library/export-excel`, params })
  },
  /**
   * 获取标签列表
   */
  getTagList: async (params: any) => {
    return await request.get({ url: `/system/tag-library/pageInfo`, params })
  }
}
