import request from '@/config/axios'

// 任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。 VO
export interface TaskInfoVO {
  id: number // 任务ID，主键
  title: string // 任务标题
  description: string // 任务描述
  execCycle: number // 执行周期
  taskType: number // 任务类型，表示任务的类别，例如：1.发布任务、2.自动任务等
  priority: number // 任务优先级
  status: string // 任务状态
  startDate: Date // 任务计划开始时间
  endDate: Date // 任务计划结束时间
  parentId: number // 父任务id
  parentType: number // 父子任务类型 10 专项 父 11 专项子 20 周期父 21 周期子  30 父任务 31 子任务
  taskStep: number // 执行到第几
  taskTotal: number // 总共几步
}

// 任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。 API
export const TaskInfoApi = {
  // 查询任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。分页
  getTaskInfoPage: async (params: any) => {
    return await request.get({ url: `/system/task-info/page`, params })
  },

  // 查询任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。详情
  getTaskInfo: async (id: any) => {
    return await request.get({ url: `/system/task-info/get?id=` + id })
  },

  // 新增任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。
  createTaskInfo: async (data) => {
    return await request.post({ url: `/system/task-info/create`, data })
  },

  // 修改任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。
  updateTaskInfo: async (data) => {
    return await request.put({ url: `/system/task-info/update`, data })
  },

  // 删除任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。
  deleteTaskInfo: async (id: number) => {
    return await request.delete({ url: `/system/task-info/delete?id=` + id })
  },

  // 导出任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。 Excel
  exportTaskInfo: async (params) => {
    return await request.download({ url: `/system/task-info/export-excel`, params })
  },

    // 导出任务表，用于存储所有的任务信息，任务可由不同用户创建并管理。 Excel
  taskExec: async (data) => {
    return await request.put({ url: `/system/task-info/taskExec`, data })
  },
  // 任务审核
  audit: async (id : number) => {
    return await request.put({ url: `/system/task-info/audit?id=` + id })
  },

}
